@@ -186,7 +186,7 @@ class Installer:
             GObject.idle_add(self._idle_cache_load_done)
         else:
             if self.remotes_changed:
-                print("PearlInstall: Flatpak remotes have changed, forcing a new cache.")
+                print("Installer: Flatpak remotes have changed, forcing a new cache.")
 
             self.cache.force_new_cache_async(self._idle_cache_load_done)
 
@@ -229,9 +229,6 @@ class Installer:
         fp_remotes = self.list_flatpak_remotes()
 
         for remote_info in fp_remotes:
-            if remote_info.noenumerate:
-                continue
-
             real_remote_count += 1
 
             item = "%s::%s::%s" % (remote_info.name, remote_info.url, str(remote_info.disabled))
@@ -253,9 +250,6 @@ class Installer:
         fp_remotes = self.list_flatpak_remotes()
 
         for remote_info in fp_remotes:
-            if remote_info.noenumerate:
-                continue
-
             item = "%s::%s::%s" % (remote_info.name, remote_info.url, str(remote_info.disabled))
 
             new_remotes.append(item)
@@ -448,13 +442,13 @@ class Installer:
 
         return pkginfo.get_description(comp)
 
-    def get_icon(self, pkginfo):
+    def get_icon(self, pkginfo, size):
         """
         Returns the icon name (or path) to display for the package
         """
         comp = self._get_backend_component(pkginfo)
 
-        return pkginfo.get_icon(comp)
+        return pkginfo.get_icon(pkginfo, comp, size)
 
     def get_screenshots(self, pkginfo):
         """
@@ -548,22 +542,3 @@ class Installer:
 
     def _run_client_callback(self, task):
         GObject.idle_add(task.client_finished_cb, task.pkginfo, task.error_message)
-
-def interact():
-    import readline
-    import code
-    variables = globals().copy()
-    variables.update(locals())
-    shell = code.InteractiveConsole(variables)
-    shell.interact()
-
-# Debugging - you can run installer.py on its own, and test things with the Installer (i)
-
-if __name__ == "__main__":
-    signal.signal(signal.SIGINT, signal.SIG_DFL)
-
-    i = Installer()
-    i.init(ready_callback=interact)
-
-    ml = GLib.MainLoop.new(None, True)
-    ml.run()
